==> zanata-client-commands-3.4.2-sources.jar: org/zanata/client/commands/Messages.java <==
/*
 * Copyright 2013, Red Hat, Inc. and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.zanata.client.commands;

import java.util.ResourceBundle;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * This class is the central place to access resource bundle.
 *
 * @author Patrick Huang
 *         <a href="mailto:pahuang@redhat.com">pahuang@redhat.com</a>
 */
public final class Messages {
    private static final Logger log = LoggerFactory.getLogger(Messages.class);

    private static ResourceBundle bundle = ResourceBundle.getBundle("prompts");

    public static String _(String key) {
        if (bundle.containsKey(key)) {
            return bundle.getString(key);
        }
        log.error(
                "Cannot find key [{}] in resource bundle. Please report a bug to developer.",
                key);
        return key;
    }
}

==> zanata-client-commands-3.8.0-sources.jar: org/zanata/client/commands/Messages.java <==
/*
 * Copyright 2013, Red Hat, Inc. and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.zanata.client.commands;

import java.text.MessageFormat;
import java.util.ResourceBundle;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * This class is the central place to access resource bundle.
 *
 * @author Patrick Huang
 *         <a href="mailto:pahuang@redhat.com">pahuang@redhat.com</a>
 */
public final class Messages {
    private static final Logger log = LoggerFactory.getLogger(Messages.class);

    private static ResourceBundle bundle = ResourceBundle.getBundle("prompts");

    public static String _(String key) {
        if (bundle.containsKey(key)) {
            return bundle.getString(key);
        }
        log.error(
                "Cannot find key [{}] in resource bundle. Please report a bug to developer.",
                key);
        return key;
    }

    public static String format(String key, Object... args) {
        String template = _(key);
        return MessageFormat.format(template, args);
    }
}
